from setuptools import setup, find_packages

setup(
    name="sbuuid",
    version="0.1",
    packages=find_packages(),
    description="A package to generate globally unique IDs",
    author="Shouvik Bajpayee",
    author_email="shouvikbajpayee.private@gmail.com",
    url="https://github.com/shouvikbj/",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
    python_requires=">=3.6",
)
